@@ -200,8 +200,8 @@ class SchoolMosregRUAPI(BaseAPI):
         Docs: https://api.school.mosreg.ru/partners/swagger/ui/index#!/Context
         """
         
-        self.me_context = self.get(f"users/{userId}/context", model=types.Context)
-        return self.me_context
+        
+        return self.get(f"users/{userId}/context", model=types.Context)
     
     def get_user_school_memberships(self, user: int | str = "me") -> types.SchoolMemberships:
         """[GET] users/{user}/school-memberships
@@ -1043,8 +1043,7 @@ class SchoolMosregRUAPI(BaseAPI):
         Docs: https://api.school.mosreg.ru/partners/swagger/ui/index#!/Persons/Persons_Get
         """
         
-        self.me_person = self.get(f"persons/{self.check_person(person)}", model=types.Person)
-        return self.me_person
+        return self.get(f"persons/{self.check_person(person)}", model=types.Person)
 
     def get_eduGroup_students(self, eduGroup: int | str) -> list[types.Person]:
         """[GET] edu-groups/{eduGroup}/students
@@ -1247,8 +1246,7 @@ class SchoolMosregRUAPI(BaseAPI):
         Docs: https://api.school.mosreg.ru/partners/swagger/ui/index#!/Users/Users_Get
         """
         
-        self.me_user = self.get(f"users/{user}", model=types.User)
-        return self.me_user
+        return self.get(f"users/{user}", model=types.User)
     
     def get_user_roles(self, user: str | int = "me") -> list[int | None] | None:
         """[GET] users/{user}/roles | users/me/roles
