@@ -9,13 +9,13 @@ class AsyncSchoolMosregRUAPI(AsyncBaseAPI):
     
     async def check_person(self, value):
         if value == "me":
-            return (self.me_context).personId if self.me_context else (await self.get_user()).personId
+            return (await self.get_user()).personId
         else:
             return value
         
     async def check_user(self, value):
         if value == "me":
-            return (self.me_user).id if self.me_user else (await self.get_user()).id
+            return (await self.get_user()).id
         else:
             return value
     
@@ -201,8 +201,7 @@ class AsyncSchoolMosregRUAPI(AsyncBaseAPI):
         Docs: https://api.school.mosreg.ru/partners/swagger/ui/index#!/Context
         """
         
-        self.me_context = await self.get(f"users/{userId}/context", model=types.Context)
-        return self.me_context
+        return await self.get(f"users/{userId}/context", model=types.Context)
     
     async def get_user_school_memberships(self, user: int | str = "me") -> types.SchoolMemberships:
         """[GET] users/{user}/school-memberships
@@ -1049,8 +1048,8 @@ class AsyncSchoolMosregRUAPI(AsyncBaseAPI):
         Docs: https://api.school.mosreg.ru/partners/swagger/ui/index#!/Persons/Persons_Get
         """
         
-        self.me_person = await self.get(f"persons/{await self.check_person(person)}", model=types.Person)
-        return self.me_person
+        
+        return await self.get(f"persons/{await self.check_person(person)}", model=types.Person)
 
     async def get_eduGroup_students(self, eduGroup: int | str) -> list[types.Person]:
         """[GET] edu-groups/{eduGroup}/students
@@ -1253,8 +1252,7 @@ class AsyncSchoolMosregRUAPI(AsyncBaseAPI):
         Docs: https://api.school.mosreg.ru/partners/swagger/ui/index#!/Users/Users_Get
         """
         
-        self.me_user = await self.get(f"users/{user}", model=types.User)
-        return self.me_user
+        return await self.get(f"users/{user}", model=types.User)
     
     async def get_user_roles(self, user: str | int = "me") -> list[int | None] | None:
         """[GET] users/{user}/roles | users/me/roles
